@@ -198,3 +198,10 @@ class BakeryTest(TestCase):
 
     def test_unpublish_cmd(self):
         pass
+
+    def test_tasks(self):
+        try:
+            from bakery import tasks
+            tasks
+        except ImportError:
+            pass
